Type: Package
Package: countrycode
Title: Convert Country Names and Country Codes
Version: 1.8.0
Authors@R: 
    c(person(given = "Vincent",
             family = "Arel-Bundock",
             role = c("aut", "cre"),
             email = "vincent.arel-bundock@umontreal.ca",
             comment = c(ORCID = "0000-0003-2042-7063")),
      person(given = "CJ",
             family = "Yetman",
             role = "ctb",
             email = "cj@cjyetman.com",
             comment = c(ORCID = "0000-0001-5099-9500")),
      person(given = "Nils",
             family = "Enevoldsen",
             role = "ctb",
             email = "nils@wlonk.com",
             comment = c(ORCID = "0000-0001-7195-4117")),
      person("Etienne", "Bacher",
             email = "etienne.bacher@protonmail.com",
             role = "ctb",
             comment = c(ORCID = "0000-0002-9271-5075")),
      person(given = "Samuel",
             family = "Meichtry",
             role = "ctb",
             email = "samuel.meichtry@bj.admin.ch",
             comment = c(ORCID = "0000-0003-2165-791X")))
Description: Standardize country names, convert them into one of 40
    different coding schemes, convert between coding schemes, and assign
    region descriptors.
License: GPL-3
URL: https://vincentarelbundock.github.io/countrycode/
BugReports: https://github.com/vincentarelbundock/countrycode/issues
Depends: R (>= 2.10)
Suggests: altdoc, eurostat, testthat, tibble, ISOcodes, utf8
Encoding: UTF-8
LazyData: yes
LazyLoad: yes
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-15 19:35:14 UTC; vincent
Author: Vincent Arel-Bundock [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2042-7063>),
  CJ Yetman [ctb] (ORCID: <https://orcid.org/0000-0001-5099-9500>),
  Nils Enevoldsen [ctb] (ORCID: <https://orcid.org/0000-0001-7195-4117>),
  Etienne Bacher [ctb] (ORCID: <https://orcid.org/0000-0002-9271-5075>),
  Samuel Meichtry [ctb] (ORCID: <https://orcid.org/0000-0003-2165-791X>)
Maintainer: Vincent Arel-Bundock <vincent.arel-bundock@umontreal.ca>
Repository: CRAN
Date/Publication: 2026-04-16 05:10:13 UTC
Built: R 4.5.2; ; 2026-04-17 09:02:21 UTC; unix
