variations <- list(


  #"Åland Islands" = c(
    #"Aland Islands",
    #"aland islands",
    #"Åland Islands",
    #"åland islands"
  #),

  "Suriname" = c(
    "Dutch Guyana",
    "Dutch Guiana"
  ),
  "French Guiana" = c(
    "French Guiana",
    "French Guyana"
  ),
  "Guyana" = c(
    "British Guiana",
    "British Guyana"
  ),

  "Congo - Brazzaville" = c(
    "republic of congo",
    "republic of the congo",
    "congo, republic of the",
    "congo, republic",
    "congo, rep.",
    "congo-brazzaville",
    "french congo"
  ),

  "Congo - Kinshasa" = c(
    "democratic republic of the congo",
    "congo, democratic republic of the",
    "dem rep of the congo",
    "the democratic republic of congo",
    "congo, dem. rep.",
    "dr congo",
    "drc",
    "droc",
    "rdc",
    "congo-kinshasa",
    "congo-zaire",
    "zaire",
    "belgian congo",
    "congo free state",
    "D.R. Congo",
    "DR Congo",
    "Democratic Republic of Congo"
    # accented regexes do not work on Windows. They are not officially supported anyway
    #"republic of the congo-léopoldville",
    # "rép. démocratique du congo",
  ),


  "China" = c(
    "People's Republic of China",
    "China, People's Republic",
    "China"
  ),

  "Hong Kong SAR China" = c(
    "Hong Kong, China",
    "Hong Kong"
  ),

  "Macao SAR China" = c(
    "Macau, China",
    "Macao, China",
    "Macau",
    "Macao"
  ),

  "Taiwan" = c(
    x = "Republic of China",
    x = "Taiwan, Province of China",
    x = "Taiwan"
  ),


  "Ireland" = c(
    "Republic of Ireland",
    "Ireland"
  ),

  "Italy" = c(
    "Italian Republic"
  ),

  "Martinique" = c(
    "France, Martinique",
    "Martinique, France"
  ),

  "North Korea" = c(
    "Democratic People's Republic of Korea",
    "DPRK",
    "Korea, Dem. Rep.",
    "DPR Korea",
    "D.P.R. Korea",
    "D.P.R Korea",
    "Korea DPR",
    "Korea D.P.R.",
    "Korea, DPR",
    "Korea, D.P.R.",
    "Korea, North",
    "Korea North",
    "Korea, Democratic People's Republic",
    "Korea (the Democratic People's Republic of)",
    "North Korea"
  ),

  "North Macedonia" = c(
    "fyrom"
  ),

  "South Africa" = c(
    "South Africa",
    "South-Africa"
  ),

  "South Korea" = c(
    "Korea, Republic of",
    "Korea, Rep. of",
    "Korea, South",
    "Korea South",
    "Republic of Korea",
    "Rep. of Korea",
    "South Korea"
  ),

  "Turkey" = c(
    "Turkey",
    "Türkiye"
  ),

  "United Arab Emirates" = c(
    "emirates",
    "united arab em.",
    "uae",
    "u.a.e."
  ),

  "United Kingdom" = c(
    "u.k.",
    "United Kingdom",
    "The United Kingdom",
    "United Kingdom of Great Britain",
    "United Kingdom of Great Britain and Northern Ireland"
  ),

  "United States" = c(
    "u.s.",
    "U.S.A.",
    "United States",
    "USA"
  ),

  "United States Minor Outlying Islands (the)" = c(
    "United States Minor Outlying Islands",
    "US Minor Outlying Islands",
    "U.S. Minor Outlying Islands",
    "Minor Outlying Islands US",
    "Minor Outlying Islands U.S.",
    "Minor Outlying Islands, US",
    "Minor Outlying Islands, U.S."
  ),

  "U.S. Virgin Islands" = c(
    "United States Virgin Islands",
    "US Virgin Islands",
    "U.S. Virgin Islands",
    "Virgin Islands, US",
    "Virgin Islands, U.S.",
    "Virgin Islands, (U.S.)",
    "Virgin Islands, (US)",
    "Virgin Islands US",
    "Virgin Islands U.S.",
    "Virgin Islands (U.S.)",
    "Virgin Islands (US)"
  ),

  "Yemen" = c(
    "yemen",
    "republic of yemen"
  ),

  "Yemen Arab Republic" = c(
    'yemen arab republic',
    'north yemen',
    'yemen (sana\'a)'
  ),

  "Yemen People's Republic" = c(
    'yemen people\'s republic',
    'people\'s democratic republic of yemen',
    'south yemen',
    'democratic yemen',
    'yemen (aden)'
  )

)
