#' List of CLDR country name codes and associated examples
#'
#' \itemize{
#'   \item Code: CLDR code
#'   \item Example: French Southern Territories in different languages
#' }
#' @docType data
#' @keywords datasets
#' @name cldr_examples
#' @usage cldr_examples
#' @format data frame
NULL
