#' A dataframe of alternative country names in many languages. Used internally by
#' the `countryname` function.
#'
#' @docType data
#' @keywords datasets
#' @name countryname_dict
#' @format dataframe
NULL
